ams.opt.objective
=================

.. automodule:: ams.opt.objective

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
   
      Objective
   
   

   
   
   



